@@ -20,11 +20,9 @@ from kubernetes.client.api.authorization_v1_api import AuthorizationV1Api
 from kubernetes.client.api.autoscaling_api import AutoscalingApi
 from kubernetes.client.api.autoscaling_v1_api import AutoscalingV1Api
 from kubernetes.client.api.autoscaling_v2_api import AutoscalingV2Api
-from kubernetes.client.api.autoscaling_v2beta1_api import AutoscalingV2beta1Api
 from kubernetes.client.api.autoscaling_v2beta2_api import AutoscalingV2beta2Api
 from kubernetes.client.api.batch_api import BatchApi
 from kubernetes.client.api.batch_v1_api import BatchV1Api
-from kubernetes.client.api.batch_v1beta1_api import BatchV1beta1Api
 from kubernetes.client.api.certificates_api import CertificatesApi
 from kubernetes.client.api.certificates_v1_api import CertificatesV1Api
 from kubernetes.client.api.coordination_api import CoordinationApi
@@ -34,10 +32,8 @@ from kubernetes.client.api.core_v1_api import CoreV1Api
 from kubernetes.client.api.custom_objects_api import CustomObjectsApi
 from kubernetes.client.api.discovery_api import DiscoveryApi
 from kubernetes.client.api.discovery_v1_api import DiscoveryV1Api
-from kubernetes.client.api.discovery_v1beta1_api import DiscoveryV1beta1Api
 from kubernetes.client.api.events_api import EventsApi
 from kubernetes.client.api.events_v1_api import EventsV1Api
-from kubernetes.client.api.events_v1beta1_api import EventsV1beta1Api
 from kubernetes.client.api.flowcontrol_apiserver_api import FlowcontrolApiserverApi
 from kubernetes.client.api.flowcontrol_apiserver_v1beta1_api import FlowcontrolApiserverV1beta1Api
 from kubernetes.client.api.flowcontrol_apiserver_v1beta2_api import FlowcontrolApiserverV1beta2Api
@@ -46,20 +42,17 @@ from kubernetes.client.api.internal_apiserver_v1alpha1_api import InternalApiser
 from kubernetes.client.api.logs_api import LogsApi
 from kubernetes.client.api.networking_api import NetworkingApi
 from kubernetes.client.api.networking_v1_api import NetworkingV1Api
+from kubernetes.client.api.networking_v1alpha1_api import NetworkingV1alpha1Api
 from kubernetes.client.api.node_api import NodeApi
 from kubernetes.client.api.node_v1_api import NodeV1Api
-from kubernetes.client.api.node_v1alpha1_api import NodeV1alpha1Api
-from kubernetes.client.api.node_v1beta1_api import NodeV1beta1Api
 from kubernetes.client.api.openid_api import OpenidApi
 from kubernetes.client.api.policy_api import PolicyApi
 from kubernetes.client.api.policy_v1_api import PolicyV1Api
-from kubernetes.client.api.policy_v1beta1_api import PolicyV1beta1Api
 from kubernetes.client.api.rbac_authorization_api import RbacAuthorizationApi
 from kubernetes.client.api.rbac_authorization_v1_api import RbacAuthorizationV1Api
 from kubernetes.client.api.scheduling_api import SchedulingApi
 from kubernetes.client.api.scheduling_v1_api import SchedulingV1Api
 from kubernetes.client.api.storage_api import StorageApi
 from kubernetes.client.api.storage_v1_api import StorageV1Api
-from kubernetes.client.api.storage_v1alpha1_api import StorageV1alpha1Api
 from kubernetes.client.api.storage_v1beta1_api import StorageV1beta1Api
 from kubernetes.client.api.version_api import VersionApi
